<a id="mypy-boto3-discovery"></a>

# mypy-boto3-discovery

[![PyPI - types-aiobotocore-discovery](https://img.shields.io/pypi/v/types-aiobotocore-discovery.svg?color=blue)](https://pypi.org/project/types-aiobotocore-discovery)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-discovery.svg?color=blue)](https://pypi.org/project/types-aiobotocore-discovery)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-discovery?color=blue)](https://pypistats.org/packages/types-aiobotocore-discovery)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.ApplicationDiscoveryService 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/discovery.html#ApplicationDiscoveryService)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-discovery docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_discovery/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-discovery](#mypy-boto3-discovery)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `ApplicationDiscoveryService`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `ApplicationDiscoveryService` service.

```bash
python -m pip install types-aiobotocore[discovery]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[discovery]` in your environment:
  `python -m pip install 'types-aiobotocore[discovery]'`

Both type checking and auto-complete should work for
`ApplicationDiscoveryService` service. No explicit type annotations required,
write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[discovery]` in your environment:
  `python -m pip install 'types-aiobotocore[discovery]'`

Both type checking and auto-complete should work for
`ApplicationDiscoveryService` service. No explicit type annotations required,
write your `aiobotocore` code as usual. Auto-complete can be slow on big
projects or if you have a lot of installed `types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[discovery]` in your environment:
  `python -m pip install 'types-aiobotocore[discovery]'`
- Run `mypy` as usual

Type checking should work for `ApplicationDiscoveryService` service. No
explicit type annotations required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[discovery]` in your environment:
  `python -m pip install 'types-aiobotocore[discovery]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ApplicationDiscoveryService` service. No
explicit type annotations required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ApplicationDiscoveryServiceClient` provides annotations for
`session.create_client("discovery")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_discovery import ApplicationDiscoveryServiceClient

session = get_session()
with async session.create_client("discovery") as client:
    client: ApplicationDiscoveryServiceClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_discovery.paginator` module contains type annotations for
all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_discovery import ApplicationDiscoveryServiceClient
from types_aiobotocore_discovery.paginator import (
    DescribeAgentsPaginator,
    DescribeContinuousExportsPaginator,
    DescribeExportConfigurationsPaginator,
    DescribeExportTasksPaginator,
    DescribeTagsPaginator,
    ListConfigurationsPaginator,
)

session = get_session()
with async session.create_client("discovery") as client:
    client: ApplicationDiscoveryServiceClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        describe_agents_paginator: DescribeAgentsPaginator = client.get_paginator("describe_agents")
        describe_continuous_exports_paginator: DescribeContinuousExportsPaginator = client.get_paginator("describe_continuous_exports")
        describe_export_configurations_paginator: DescribeExportConfigurationsPaginator = client.get_paginator("describe_export_configurations")
        describe_export_tasks_paginator: DescribeExportTasksPaginator = client.get_paginator("describe_export_tasks")
        describe_tags_paginator: DescribeTagsPaginator = client.get_paginator("describe_tags")
        list_configurations_paginator: ListConfigurationsPaginator = client.get_paginator("list_configurations")
    ```







### Literals

`types_aiobotocore_discovery.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_discovery.literals import (
    AgentStatusType,
    BatchDeleteImportDataErrorCodeType,
    ConfigurationItemTypeType,
    ContinuousExportStatusType,
    DataSourceType,
    DescribeAgentsPaginatorName,
    DescribeContinuousExportsPaginatorName,
    DescribeExportConfigurationsPaginatorName,
    DescribeExportTasksPaginatorName,
    DescribeTagsPaginatorName,
    ExportDataFormatType,
    ExportStatusType,
    ImportStatusType,
    ImportTaskFilterNameType,
    ListConfigurationsPaginatorName,
    orderStringType,
    ServiceName,
    PaginatorName,
)

def check_value(value: AgentStatusType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_discovery.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_discovery.type_defs import (
    AgentConfigurationStatusTypeDef,
    AgentInfoTypeDef,
    AgentNetworkInfoTypeDef,
    AssociateConfigurationItemsToApplicationRequestRequestTypeDef,
    BatchDeleteImportDataErrorTypeDef,
    BatchDeleteImportDataRequestRequestTypeDef,
    BatchDeleteImportDataResponseTypeDef,
    ConfigurationTagTypeDef,
    ContinuousExportDescriptionTypeDef,
    CreateApplicationRequestRequestTypeDef,
    CreateApplicationResponseTypeDef,
    CreateTagsRequestRequestTypeDef,
    CustomerAgentInfoTypeDef,
    CustomerConnectorInfoTypeDef,
    DeleteApplicationsRequestRequestTypeDef,
    DeleteTagsRequestRequestTypeDef,
    DescribeAgentsRequestRequestTypeDef,
    DescribeAgentsResponseTypeDef,
    DescribeConfigurationsRequestRequestTypeDef,
    DescribeConfigurationsResponseTypeDef,
    DescribeContinuousExportsRequestRequestTypeDef,
    DescribeContinuousExportsResponseTypeDef,
    DescribeExportConfigurationsRequestRequestTypeDef,
    DescribeExportConfigurationsResponseTypeDef,
    DescribeExportTasksRequestRequestTypeDef,
    DescribeExportTasksResponseTypeDef,
    DescribeImportTasksRequestRequestTypeDef,
    DescribeImportTasksResponseTypeDef,
    DescribeTagsRequestRequestTypeDef,
    DescribeTagsResponseTypeDef,
    DisassociateConfigurationItemsFromApplicationRequestRequestTypeDef,
    ExportConfigurationsResponseTypeDef,
    ExportFilterTypeDef,
    ExportInfoTypeDef,
    FilterTypeDef,
    GetDiscoverySummaryResponseTypeDef,
    ImportTaskFilterTypeDef,
    ImportTaskTypeDef,
    ListConfigurationsRequestRequestTypeDef,
    ListConfigurationsResponseTypeDef,
    ListServerNeighborsRequestRequestTypeDef,
    ListServerNeighborsResponseTypeDef,
    NeighborConnectionDetailTypeDef,
    OrderByElementTypeDef,
    PaginatorConfigTypeDef,
    ResponseMetadataTypeDef,
    StartContinuousExportResponseTypeDef,
    StartDataCollectionByAgentIdsRequestRequestTypeDef,
    StartDataCollectionByAgentIdsResponseTypeDef,
    StartExportTaskRequestRequestTypeDef,
    StartExportTaskResponseTypeDef,
    StartImportTaskRequestRequestTypeDef,
    StartImportTaskResponseTypeDef,
    StopContinuousExportRequestRequestTypeDef,
    StopContinuousExportResponseTypeDef,
    StopDataCollectionByAgentIdsRequestRequestTypeDef,
    StopDataCollectionByAgentIdsResponseTypeDef,
    TagFilterTypeDef,
    TagTypeDef,
    UpdateApplicationRequestRequestTypeDef,
)

def get_structure() -> AgentConfigurationStatusTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-discovery` version is the same as related `boto3` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-discovery docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_discovery/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
